@@ -101,6 +101,25 @@ async def getImages(channel, post_id, post_size):
         result.append(fn)
     return result
 
+def addAddtionalPlaceholder(text):
+    placeholder_count = 0
+    new_text = text[:]
+    for index, c in enumerate(text):
+        if ord(c) > 256 * 256:
+            new_text[index + placeholder_count: index + placeholder_count + 1] = [c, '']
+            placeholder_count += 1
+    return new_text 
+
+async def getRawText(channel, post_id):
+    client = await getTelethonClient()
+    entity = await getChannel(client, channel)
+    post = await client.get_messages(entity, ids=post_id)
+    if not post.message:
+        return [], post
+    text = list(post.message)
+    text = addAddtionalPlaceholder(text)
+    return text, post
+
 async def getPostsTelethon(channel, min_id, limit = 1000):
     client = await getTelethonClient()
     entity = await getChannel(client, channel)
@@ -119,16 +138,4 @@ async def exitTelethon():
     if 'client' in client_cache:
         await client_cache['client'].disconnect()
         return True
-    return False
-
-def getText(soup):
-    soup = copy.copy(soup)
-    for item in soup.find_all('a'):
-        if item.get('href') and not item.get('href').startswith('?q='):
-            item.replace_with('\n\n' + item.get('href') + '\n\n')
-    for item in soup.find_all('br'):
-        item.replace_with('\n')
-    result = soup.text.strip()
-    for _ in range(5):
-        result = result.replace('\n\n\n', '\n\n')
-    return result
\ No newline at end of file
+    return False
\ No newline at end of file
